"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getCache;

function getCache(_ref) {
  var element = _ref.element,
      offsets = _ref.offsets,
      view = _ref.view,
      scroll = _ref.scroll;
  var y0 = offsets.y0,
      y1 = offsets.y1,
      x1 = offsets.x1,
      x0 = offsets.x0;
  var rect = element.getBoundingClientRect(); // rect is based on viewport -- must adjust for relative scroll container

  if (view.scrollContainer) {
    var scrollRect = view.scrollContainer.getBoundingClientRect();
    rect = {
      top: rect.top - scrollRect.top,
      right: rect.right - scrollRect.left,
      bottom: rect.bottom - scrollRect.top,
      left: rect.left - scrollRect.left
    };
  }

  var height = element.offsetHeight;
  var width = element.offsetWidth; // Y offsets

  var yPercent = y1.unit === '%' && y0.unit === '%';
  var y0Px = y0.value;
  var y1Px = y1.value;

  if (yPercent) {
    var h100 = height / 100;
    y0Px = y0.value * h100;
    y1Px = y1.value * h100;
  } // X offsets


  var xPercent = x1.unit === '%' && x0.unit === '%';
  var x0Px = x0.value;
  var x1Px = x1.value;

  if (xPercent) {
    var _h = width / 100;

    x0Px = x0.value * _h;
    x1Px = x1.value * _h;
  } // original el positions and distances


  var originTop = rect.top + scroll.y;
  var originBottom = rect.bottom + scroll.y;
  var originLeft = rect.left + scroll.x;
  var originRight = rect.right + scroll.x;
  var originTotalDistY = view.height + height;
  var originTotalDistX = view.width + width;
  var totalAbsOffY = Math.abs(y0Px) + Math.abs(y1Px);
  var totalDistY = view.height + height + totalAbsOffY;
  var totalDistTrueY = view.height + height + (y1Px > y0Px ? totalAbsOffY * -1 : totalAbsOffY);
  var totalAbsOffX = Math.abs(x0Px) + Math.abs(x1Px);
  var totalDistX = view.width + width + totalAbsOffX;
  var totalDistTrueX = view.width + width + (x1Px > x0Px ? totalAbsOffX * -1 : totalAbsOffX); // const speed = totalDistTrueY / originTotalDistY;

  var multiplierY = originTotalDistY / totalDistTrueY;
  var multiplierX = originTotalDistX / totalDistTrueX;
  var top = originTop;
  var bottom = originBottom;

  if (y0Px < 0) {
    top = top + y0Px * multiplierY;
  }

  if (y1Px > 0) {
    bottom = bottom + y1Px * multiplierY;
  }

  var left = originLeft;
  var right = originRight;

  if (x0Px < 0) {
    left = left + x0Px * multiplierX;
  }

  if (x1Px > 0) {
    right = right + x1Px * multiplierX;
  }

  return {
    height: height,
    width: width,
    top: top,
    bottom: bottom,
    left: left,
    right: right,
    totalDistY: totalDistY,
    totalDistX: totalDistX,
    originTop: originTop,
    originBottom: originBottom,
    originLeft: originLeft,
    originRight: originRight,
    originTotalDistY: originTotalDistY,
    originTotalDistX: originTotalDistX
  };
}