"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addAttributesVertical = addAttributesVertical;
exports.addAttributesHorizontal = addAttributesHorizontal;

/**
 * Takes a parallax element and caches important values that
 * cause layout reflow and paints. Stores the values as an
 * attribute object accessible on the parallax element.
 * @param {object} element
 */
function addAttributesVertical(elOuter, offsets, windowHeight, scrollY) {
  var y0 = offsets.y0,
      y1 = offsets.y1; // NOTE: Many of these cause layout and reflow so we're not
  // calculating them on every frame -- instead these values
  // are cached on the element to access later when determining
  // the element's position and offset.

  var el = elOuter;
  var rect = el.getBoundingClientRect();
  var elHeight = el.offsetHeight;
  var elWidth = el.offsetWidth;
  var yPercent = y1.unit === '%' && y0.unit === '%'; // const xPercent = x1.unit === '%' && x0.unit === '%';
  // Y offsets

  var y0Px = y0.value;
  var y1Px = y1.value;

  if (yPercent) {
    var h100 = elHeight / 100;
    y0Px = y0.value * h100;
    y1Px = y1.value * h100;
  } // original el positions and distances


  var originTop = rect.top + scrollY;
  var originBottom = rect.bottom + scrollY;
  var originTotalDist = windowHeight + elHeight;
  var totalAbsOff = Math.abs(y0Px) + Math.abs(y1Px);
  var totalDist = windowHeight + elHeight + totalAbsOff;
  var totalDistTrue = windowHeight + elHeight + (y1Px > y0Px ? totalAbsOff * -1 : totalAbsOff); // const speed = totalDistTrue / originTotalDist;

  var multiplier = originTotalDist / totalDistTrue;
  var top = originTop;
  var bottom = originBottom;

  if (y0Px < 0) {
    top = top + y0Px * multiplier;
  }

  if (y1Px > 0) {
    bottom = bottom + y1Px * multiplier;
  }

  return {
    top: top,
    bottom: bottom,
    elHeight: elHeight,
    elWidth: elWidth,
    totalDist: totalDist,
    // origins
    originTop: originTop,
    originBottom: originBottom,
    originTotalDist: originTotalDist
  };
}
/**
 * Horizontal
 * @param {object} element
 */


function addAttributesHorizontal(elOuter, offsets, viewWidth, scrollX) {
  var x0 = offsets.x0,
      x1 = offsets.x1; // NOTE: Many of these cause layout and reflow so we're not
  // calculating them on every frame -- instead these values
  // are cached on the element to access later when determining
  // the element's position and offset.

  var el = elOuter;
  var rect = el.getBoundingClientRect();
  var elHeight = el.offsetHeight;
  var elWidth = el.offsetWidth;
  var xPercent = x1.unit === '%' && x0.unit === '%'; // X offsets

  var x0Px = x0.value;
  var x1Px = x1.value;

  if (xPercent) {
    var w100 = elWidth / 100;
    x0Px = x0.value * w100;
    x1Px = x1.value * w100;
  } // original el positions and distances


  var originLeft = rect.left + scrollX;
  var originRight = rect.right + scrollX;
  var originTotalDist = viewWidth + elWidth;
  var totalAbsOff = Math.abs(x0Px) + Math.abs(x1Px);
  var totalDist = viewWidth + elWidth + totalAbsOff;
  var totalDistTrue = viewWidth + elWidth + (x1Px > x0Px ? totalAbsOff * -1 : totalAbsOff); // const speed = totalDistTrue / originTotalDist;

  var multiplier = originTotalDist / totalDistTrue;
  var left = originLeft;
  var right = originRight;

  if (x0Px < 0) {
    left = left + x0Px * multiplier;
  }

  if (x1Px > 0) {
    right = right + x1Px * multiplier;
  }

  return {
    left: left,
    right: right,
    elHeight: elHeight,
    elWidth: elWidth,
    totalDist: totalDist,
    // origins
    originLeft: originLeft,
    originRight: originRight,
    originTotalDist: originTotalDist
  };
}